## usage
```python
if __name__ == "__main__":
    selector = FileSelector(select_file=True, is_multi_file=False)
    files = selector.select_files()
    if files:
        for f in files:
            print(f)

```